from .discoverers import DiscovererList
from .parse import parse_html


__version__ = '0.3.0'
__all__ = [
    'parse_html',
    'discovery'
]


default_app_config = 'oembed.apps.OembedAppConfig'


discovery = DiscovererList()



from .models import Resource
from . import settings, utils


def parse_html(value, ajax=False):
    if not value:
        return ''

    value = str(value)
    if '<p' not in value and '</p>' not in value:
        if not value.strip().startswith('<') and not value.strip().endswith('</p>'):
            value = '<p>%s</p>' % value

    match = settings.P_REGEX.search(value)
    while match is not None and match.end() <= len(value):
        start = match.start()
        end = match.end()
        groups = match.groups()

        url = groups[0]
        if not url.startswith('http:') and not url.startswith('https:'):
            match = settings.P_REGEX.search(value, start + len(url))
            continue

        inner = '<p><a href="%(url)s">%(url)s</a></p>' % {
            'url': url
        }

        if ajax:
            inner = utils.wrap_ajax(
                utils.make_printable(url),
                'unknown'
            )
        else:
            resource = Resource.load(url)
            inner = resource.to_html()

        value = value[:start] + inner + value[end:]
        match = settings.P_REGEX.search(value, start + len(inner))

    return value



from django.views.generic.base import View
from django.http.response import HttpResponse
from .models import Resource
from .response import OEmbedResponse
from . import discovery


class OEmbedProviderView(View):
    def get(self, request):
        url = request.GET.get('url')
        if url:
            response = discovery.discover(url)
            if response:
                return response

        return HttpResponse(
            '{"error": "Resource not found"}',
            content_type='application/json',
            status=404
        )


class OEmbedAJAXView(View):
    def get(self, request):
        url = request.GET.get('url')
        callback = request.GET.get('callback')
        resource = Resource.load(url)

        return OEmbedResponse(
            width=resource.width,
            height='auto',
            kind='video',
            title=resource.title,
            html=resource.to_html(),
            jsonp_callback=callback
        )
